/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: GuiInputString.h,v 1.9 2007/12/03 05:43:53 bowkenken Exp $
***************************************************************/

#ifndef GUI_INPUT_STRING_H
#define GUI_INPUT_STRING_H	1

////////////////////////////////////////////////////////////////
// ʸϡɥ
////////////////////////////////////////////////////////////////

class GuiInputString {

	//////// ץ饤١ȡСѿ ////////
private:

#ifdef D_WS
	void *mWin;
#endif // D_WS

#ifdef D_GTK
	GtkWidget *mWin;
	GtkWidget *mTitle;
#endif // D_GTK

	//////// ѥ֥åСѿ ////////
public:

#ifdef D_WS
#endif // D_WS

#ifdef D_GTK
	GtkWidget *mEntry;
#endif // D_GTK

	//////// ѥ֥åСؿ ////////
public:

	GuiInputString()
	{
#ifdef D_GTK
		mWin = NULL;
#endif // D_GTK
	}
	~GuiInputString()
	{
	}

	void init();
	void destroy();

	void draw( const char *ttl, const char *str, long len );
	void wipe();

	//////// ץ饤١ȡСؿ ////////
private:

	void newWin();
};

#endif /* GUI_INPUT_STRING_H */
